BloomTextValue class

Text string value expression wrapper.

Example:

const val = BloomTextValue('active');
assert(val.raw == 'active');
Inheritance

Constructors

BloomTextValue(String value)
Creates a text BloomValue wrapping value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
raw String
Unwraps the underlying raw Dart value (e.g. int, String, List<dynamic>, or null).
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying text string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override